      subroutine bbkk(iwdth,iwgt,wgt,arg,u1,n1,p1,u,n,p,g,mass,wdth)
c----------------------------------------------------------------------c
c Returns a four vector array
c           u_m=g*u1_n*(-g_nm + p_n*p_m/mv2)/(p^2-mv2).
c
c Input: iwdth=0 - fixed width of the vector particle,
c              1,2,... - running width of the vector particle,
c        iwgt = 1 => include a factor wgt*e^(i*arg)*f(s/mass**2),
c               else => do not include the factor,
c        u1 - polarisation vector,
c        n1,n - No. of polarisation states, should be n1=n,
c        p1 - four momentum,
c        g - boson-boson coupling between u1 and u,
c        mass,wdth - mass and width of u
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 11 April, 2014; modified on 5 March, 2015,
c 12 March, 2015 (call to subroutine runwidth added)
c 20 March, 2015 (call to subroutine runwidth changed)
c 24 March, 2015 (a call to subroutine weightfactor introduced)
c----------------------------------------------------------------------c

      implicit none

      integer, parameter :: dp=kind(1.d0)
      real(dp) :: wgt,arg,mass,wdth
      integer :: iwdth,iwgt,n1,n,i1
      real(dp), dimension(0:3) :: p1,p
      complex(dp) :: u1(0:3,n1),u(0:3,n),g,gden,mv2,cfac

      p=-p1   ! Virtual vector boson is always incoming to the vertex.

      if (mass > 0.d0) then
       if (iwdth == 0) then
        mv2=cmplx(mass**2,-mass*wdth,dp)
       else
        call runwidth(iwdth,p,mass,wdth,mv2)
       end if
       gden=g/(cmplx(p(0)**2-p(1)**2-p(2)**2-p(3)**2,0.d0,dp)-mv2)
      else
       gden=g/cmplx(p(0)**2-p(1)**2-p(2)**2-p(3)**2,0.d0,dp)
      end if

      do i1=1,n1
       u(:,i1)=-gden*u1(:,i1) 
       if (mass > 0.d0) then
        u(:,i1)=u(:,i1)+gden*(u1(0,i1)*p(0)-u1(1,i1)*p(1)
     &                       -u1(2,i1)*p(2)-u1(3,i1)*p(3))*p/mv2
       end if
      end do ! i1

      if (iwgt > 0) then
       call weightfactor(iwgt,wgt,arg,p,mass,cfac)
       u=cfac*u
      end if

      end subroutine bbkk
