      function gllee(x,y,eps,q2,beta,eta,choice)
c----------------------------------------------------------------------c
c The LL structure function including terms of O(alpha^3) according to
c W. Beenakker et. al., hep-ph/9602351
c
c Input:  x - momentum fraction of radiating particle,
c         y=1-x,
c         q2 - scale (all 3 scales are set to be equal), not used,
c         beta=2*alpha/pi*(L-1),
c         eta=2*alpha/pi*L,
c         choice=1,2 or 3 corresponds to the 'mixed', 'eta' or 'beta'
c                choice
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 27 August, 2003, modiffied 3 October, 2003
c----------------------------------------------------------------------c


      implicit none

      integer, parameter :: dp=kind(1.d0)

      real(dp), parameter :: pi=3.141592653589793238d0, pi2=pi**2,
     &                       gammae=0.577215664901532861d0    ! Euler constant
      real(dp) :: gllee,x,y,eps,q2
      integer :: choice

      real(dp) :: eta,beta,betae,betas,betah,ddilog,lx,lx1,x2,hbe,gamma

      if (choice == 1) then   ! 'mixed' choice
       betae=beta
       betas=eta
       betah=eta
      else if (choice == 2) then   ! 'eta' choice
       betae=beta
       betas=beta
       betah=eta
      else if (choice == 3) then   ! 'beta' choice
       betae=beta
       betas=beta
       betah=beta
      else
       write(*,*)'choice =',choice,' in gllee.f is not allowed'
       stop
      end if

      hbe=0.5d0*betae

      if (y < eps) then

       gllee=exp(-hbe*gammae+0.375d0*betas)/gamma(1.d0+hbe)*hbe

      else

      lx=log(x)
      lx1=log(y)
      x2=x**2

      gllee=exp(-hbe*gammae+0.375d0*betas)/gamma(1.d0+hbe)
     &     *hbe*y**(hbe-1.d0)-0.25d0*betah*(1.d0+x)
     &     -betah**2/32.d0*((1.d0+3.d0*x2)/y*lx
     &                      +4.d0*(1.d0+x)*lx1+5.d0+x)
     &     -betah**3/384.d0*((1.d0+x)*(6.d0*ddilog(x)
     &                             +12.d0*lx1**2-3.d0*pi**2)
     &     +(1.5d0*(1.d0+8.d0*x+3.d0*x2)*lx
     &      +6.d0*(x+5.d0)*y*lx1
     &      +12.d0*(1.d0+x2)*lx*lx1
     &      -0.5d0*(1.d0+7.d0*x2)*lx**2
     &      +0.25d0*(39.d0-24.d0*x-15.d0*x2))/y)

      end if

      end
