      subroutine tbwkk(u1,n1,p1,u2,n2,p2,u,n,p,g,mass,wdth)
c----------------------------------------------------------------------c
c Returns a four vector array
c           u=u1*gamma_n*(gvm*P- + gvp*P+)*u2
c                         *(-g_mn + q_m*q_n/mv2)/(q^2-mv2).
c
c Input: 
c        g - a fermion-fermion-boson coupling.
c
c The gamma matrices are taken in the Weyl representation as in the 
c paper by K. Kolodziej, M. Zralek, Phys. Rev. D43 (1991) 3619
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 23 March, 2005; modified 31 March, 2005, 3 April, 2005, 22 March, 2006,
c                          27 April, 2006, 16 February, 2007,
c                              6/13 May, 2007 (interface changed again)
c                              20 May, 2007 (sign of p changed)
c----------------------------------------------------------------------c

      implicit none

      integer, parameter :: dp=kind(1.d0)
      integer :: n1,n2,n,i1,i2,i

      real(dp) :: mass,wdth
      real(dp), dimension(0:3) :: p1,p2,p

      complex(dp), parameter :: ocom=(0.d0,0.d0),icom=(0.d0,1.d0)
      complex(dp) :: u1(4,n1),u2(4,n2),u(0:3,n)
      complex(dp) :: den,nomm,nomp,mv2,g(2)
      complex(dp),dimension(4) :: em,ep

      p=p1+p2
c      p=-p1-p2   ! Virtual vector boson is always incoming to the vertex.

      mv2=cmplx(mass**2,-mass*wdth,dp)

      den=cmplx(p(0)**2-p(1)**2-p(2)**2-p(3)**2,0.d0,dp)-mv2
      nomp=g(1)
      nomm=g(2)

      i=0

      do i2=1,n2
      do i1=1,n1

      i=i+1

       em=(/   u1(3,i1)*u2(1,i2)
     &               +u1(4,i1)*u2(2,i2),
     &       -(u1(3,i1)*u2(2,i2)
     &               +u1(4,i1)*u2(1,i2)),
     &  +icom*(u1(3,i1)*u2(2,i2)
     &              -u1(4,i1)*u2(1,i2)),
     &        -u1(3,i1)*u2(1,i2)
     &              +u1(4,i1)*u2(2,i2)/)

      if (g(1) == ocom) then

       ep=ocom

      else

       ep=(/   u1(1,i1)*u2(3,i2)
     &              +u1(2,i1)*u2(4,i2),
     &         u1(1,i1)*u2(4,i2)
     &              +u1(2,i1)*u2(3,i2),
     &  -icom*(u1(1,i1)*u2(4,i2)
     &              -u1(2,i1)*u2(3,i2)),
     &         u1(1,i1)*u2(3,i2)
     &              -u1(2,i1)*u2(4,i2)/)

      end if

      u(:,i)=-(nomm*em+nomp*ep)/den

      if (mass > 0.d0) then
       u(:,i)=u(:,i)-(p(0)*u(0,i)-p(1)*u(1,i)
     &               -p(2)*u(2,i)-p(3)*u(3,i))*p/mv2
      end if

      end do ! i1
      end do ! i2

      end subroutine tbwkk



