      subroutine vsvsmd(ig,g,u1,p1,u2,p2,u3,p3,u4,mat)
c----------------------------------------------------------------------c
c Returns a matrix element array for a quartic gauge-Higgs boson vertex 
c
c Input: ig=0(fixed coupling g)/else(running coupling g),
c        p1,p2,p3 - four momenta,
c        u1,u3 - vector,
c        u2,u4 - sclar,
c        g - a quartic scalar-gauge-boson coupling.
c All four momenta are cosidered as incoming to the vertex.
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 17 May, 2007; modified 
c 1 April, 2105:
c a call to s-dependent coupling implemented
c----------------------------------------------------------------------c

      implicit none

      integer, parameter :: dp=kind(1.d0)
      integer :: ig
      real(dp), dimension(0:3) :: p1,p2,p3,p
      complex(dp) :: u1(0:3),u3(0:3),u2(1),u4(1),mat,g,rg

      p=-p1-p2-p3

      if (ig == 0) then
       rg=g
      else
       call runcoupl(ig,p,rg)
      end if

      mat=-rg*u2(1)*u4(1)*(u1(0)*u3(0)-u1(1)*u3(1)
     &                    -u1(2)*u3(2)-u1(3)*u3(3))

c The extra minus sign results from missing i^2 if a quartic coupling 
c is present

      end subroutine vsvsmd
